@@ -1,17 +1,12 @@
 package Memoize::AnyDBM_File;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '1.05';
-@ISA = qw(DB_File GDBM_File Memoize::NDBM_File Memoize::SDBM_File ODBM_File) unless @ISA;
+$VERSION = '1.06';
 
-my $mod;
-for $mod (@ISA) {
-#  (my $truemod = $mod) =~ s/^Memoize:://;
-#  my $file = "$mod.pm";
-#  $file =~ s{::}{/}g;
+for my $mod (qw(DB_File GDBM_File Memoize::NDBM_File SDBM_File ODBM_File)) {
   if (eval "require $mod") {
     print STDERR "AnyDBM_File => Selected $mod.\n" if $Verbose;
-    @ISA = ($mod);	# if we leave @ISA alone, warnings abound
+    @ISA = $mod;
     return 1;
   }
 }
